==> Acme-ManekiNeko-0.01.tar.gz: Acme-ManekiNeko-0.01/ManekiNeko.pm <==
package Acme::ManekiNeko;

our $VERSION='0.01';
our $MANEKINEKO=<<'EOM';

             db         db
            dpqb       dp8b
            8b qb_____dp_88
            88/ .        `p
            q'.            \
           .'.  .-.    ,-.  `--.
           |.  / 0 \  / 0 \ |   \
           |.  `.__   ___.' | \\/
           |.       "       | (
            \.    `-'-'    ,' |
           _/`------------'. .|
          /.  \\::(::[];)||.. \
         /.  ' \.`:;;;;'''/`. .|
        |.   |/ `;--._.__/  |..|
        |.  _/_,'''',,`.    `:.'
        |.     ` / ,  ',`.   |/
         \.   -'/\/     ',\  |\
          /\__-' /\ /     ,. |.\
         /. .|  '  /-.    ,: |..\
        :.  .|    /| | ,  ,||. ..:
        |.  .`     | '//` ,:|.  .|
        |..  .\      //\/ ,|.  ..|
         \.   .\     <./  ,'. ../
          \_ ,..`.__    _,..,._/
            `\|||/  `--'\|||/'

EOM

1;

=pod

=head1 NAME

Acme::ManekiNeko

=head1 SYNOPSIS

    use Acme::ManekiNeko; # This will make your Perl programs a lot more lucky

=head1 DESCRIPTION

"According to ancient legend, this cat stood in the doorway of the
Gotoku-ji temple and raised her paw in the traditional Japanese
beckoning gesture to a feudal lord who was passing by. The feudal lord
followed the cat into the temple and instantly, a lightning bolt
struck the place where the lord had been standing. Thus the cat had
saved his life. From then on, the Maneki Neko has been considered an
incarnation of the Goddess of Mercy."

Now your Perl programs can also benefit from good fortune by using
this module which invokes the image of Maneki Neko giving your
code luck.

=head1 AUTHOR

Greg McCarroll <greg@mccarroll.demon.co.uk>

=end

==> Acme-ManekiNeko-0.02.tar.gz: Acme-ManekiNeko-0.02/ManekiNeko.pm <==
package Acme::ManekiNeko;

use strict;
use warnings;

our $VERSION='0.02';
our $MANEKINEKO=<<'EOM';

             db         db
            dpqb       dp8b
            8b qb_____dp_88
            88/ .        `p
            q'.            \
           .'.  .-.    ,-.  `--.
           |.  / 0 \  / 0 \ |   \
           |.  `.__   ___.' | \\/
           |.       "       | (
            \.    `-'-'    ,' |
           _/`------------'. .|
          /.  \\::(::[];)||.. \
         /.  ' \.`:;;;;'''/`. .|
        |.   |/ `;--._.__/  |..|
        |.  _/_,'''',,`.    `:.'
        |.     ` / ,  ',`.   |/
         \.   -'/\/     ',\  |\
          /\__-' /\ /     ,. |.\
         /. .|  '  /-.    ,: |..\
        :.  .|    /| | ,  ,||. ..:
        |.  .`     | '//` ,:|.  .|
        |..  .\      //\/ ,|.  ..|
         \.   .\     <./  ,'. ../
          \_ ,..`.__    _,..,._/
            `\|||/  `--'\|||/'

EOM

1;

=pod

=head1 NAME

Acme::ManekiNeko

=head1 SYNOPSIS

    use Acme::ManekiNeko; # This will make your Perl programs a lot more lucky

=head1 HISTORY

I took this module down ages ago, but I kept seeing references to it
where people had actually like this random bit of sillyness and I kicked myself 
that I had lost the code. Enter backpan, thanks!

    http://www.runme.org/project/+AcmeManekiNeko/
    http://www.hyuki.com/yukiwiki/wiki.cgi?Acme%3A%3AManekiNeko

=head1 DESCRIPTION

"According to ancient legend, this cat stood in the doorway of the
Gotoku-ji temple and raised her paw in the traditional Japanese
beckoning gesture to a feudal lord who was passing by. The feudal lord
followed the cat into the temple and instantly, a lightning bolt
struck the place where the lord had been standing. Thus the cat had
saved his life. From then on, the Maneki Neko has been considered an
incarnation of the Goddess of Mercy."

Now your Perl programs can also benefit from good fortune by using
this module which invokes the image of Maneki Neko giving your
code luck.

=head1 AUTHOR

Greg McCarroll <greg@mccarroll.org.uk>

=end
